==> jsxgettext-0.6.2.tgz: package/lib/parsers/jade.js <==
"use strict";

var jade = require('jade');

// From MDN:
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions#Using_Special_Characters
function escapeRegExp(string) {
  return string.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1");
}

function parseJade(str, options) {
  options = options || {};

  var parser = new jade.Parser(str);
  var lexer = parser.lexer;
  var token;

  options.keyword = options.keyword || ['gettext'];

  var gettextRegexPrefix = '(?:' + options.keyword.map(escapeRegExp).join('|') + ')';
  var gettexRegex = new RegExp(gettextRegexPrefix + '(?:\\(\"[^"]+\"|\\(\'[^\']+\')', 'gi');

  function extractGettext(str) {
    if (typeof(str) !== 'string') return '';

    var tmp = str.match(gettexRegex) || [];
    return tmp.map(function (t) {
      return t + ')';
    }).join(';');
  }

  function extractFromObj(key) {
    /* jshint -W040 */
    return extractGettext(this[key]);
  }

  function isEmpty(obj) {
    return obj.length;
  }

  var buf = [], lineN, tmp;
  do {
    token = lexer.next();
    lineN = token.line - 1;
    switch (token.type) {
      case 'attrs':
        tmp = Object.keys(token.attrs).map(extractFromObj, token.attrs).filter(isEmpty);
        if (tmp.length)
          buf[lineN] = tmp.join(';') + ';';
        break;
      case 'text':
      case 'code':
        tmp = extractGettext(token.val);
        if (tmp.length) buf[lineN] = tmp + ';';
        break;
    }
  } while (token.type !== 'eos');

  return buf.join('\n');
}

// generate extracted strings file from Jade templates
exports.jade = function Jade(jadeSources, options) {
  Object.keys(jadeSources).forEach(function (filename) {
    jadeSources[filename] = parseJade(jadeSources[filename], options);
  });

  return [jadeSources, options];
};

==> jsxgettext-0.8.0.tgz: package/lib/parsers/jade.js <==
"use strict";

var jade = require('jade');

// From MDN:
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions#Using_Special_Characters
function escapeRegExp(string) {
  return string.replace(/([.*+?^=!:${}()|\[\]\/\\])/g, "\\$1");
}

function parseJade(str, options) {
  options = options || {};

  var parser = new jade.Parser(str);
  var lexer = parser.lexer;
  var token;

  options.keyword = options.keyword || ['gettext'];

  var gettextRegexPrefix = '(?:' + options.keyword.map(escapeRegExp).join('|') + ')';
  var gettexRegex = new RegExp(gettextRegexPrefix + '(?:\\(\"[^"]+\"|\\(\'[^\']+\')', 'gi');

  function extractGettext(str) {
    if (typeof(str) !== 'string') return '';

    var tmp = str.match(gettexRegex) || [];
    return tmp.map(function (t) {
      return t + ')';
    }).join(';');
  }

  function extractFromObj(key) {
    /* jshint -W040 */
    return extractGettext(this[key].val);
  }

  var buf = [];

  function append(text, offset) {
    /* jshint -W040 */
    if (this.type === 'attrs') {
      // offset for attribute tokens are invalid
      // we treat all attr tokens to be on the same line as the first one =(
      offset = 0;
    }
    var line = this.line + (offset || 0) - 1;
    if (text.length) {
      buf[line] = [buf[line], text, ';'].join('');
    }
  }

  do {
    token = lexer.next();
    switch (token.type) {
      case 'attrs':
        Object.keys(token.attrs)
          .map(extractFromObj, token.attrs)
          .forEach(append, token);
        break;
      case 'text':
      case 'code':
        append.call(token, extractGettext(token.val));
        break;
      case 'pipeless-text':
        token.line -= token.val.length - 1;
        token.val
          .map(extractGettext)
          .forEach(append, token);
        break;
      case 'comment':
        if (/^\s*L10n:/.test(token.val)) {
          append.call(token, ['/*', token.val, '*/'].join(''));
        }
        break;
    }
  } while (token.type !== 'eos');

  return buf.join('\n');
}

// generate extracted strings file from Jade templates
exports.jade = function Jade(jadeSources, options) {
  Object.keys(jadeSources).forEach(function (filename) {
    jadeSources[filename] = parseJade(jadeSources[filename], options);
  });

  return [jadeSources, options];
};
